.. contents::

Methods
-------

In what follows

- "✔" mark means that method is supported,
  but not covered with tests (or not completely covered),
- "✘" mark means that method is supported
  and covered with tests.

ACCOUNT
~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/account/get-details>`__
- `Get Created Lists <https://developers.themoviedb.org/3/account/get-created-lists>`__
- `Get Favorite Movies <https://developers.themoviedb.org/3/account/get-favorite-movies>`__
- `Get Favorite TV Shows <https://developers.themoviedb.org/3/account/get-favorite-tv-shows>`__
- `Mark as Favorite <https://developers.themoviedb.org/3/account/mark-as-favorite>`__
- `Get Rated Movies <https://developers.themoviedb.org/3/account/get-rated-movies>`__
- `Get Rated TV Shows <https://developers.themoviedb.org/3/account/get-rated-tv-shows>`__
- `Get Rated TV Episodes <https://developers.themoviedb.org/3/account/get-rated-tv-episodes>`__
- `Get Movie Watchlist <https://developers.themoviedb.org/3/account/get-movie-watchlist>`__
- `Get TV Show Watchlist <https://developers.themoviedb.org/3/account/get-tv-show-watchlist>`__
- `Add to Watchlist <https://developers.themoviedb.org/3/account/add-to-watchlist>`__

AUTHENTICATION
~~~~~~~~~~~~~~
- ✘ `Create Request Token <https://developers.themoviedb.org/3/authentication/create-request-token>`__
- ✘ `Create Session <https://developers.themoviedb.org/3/authentication/create-session>`__
- ✘ `Create Session With Login (do not use) <https://developers.themoviedb.org/3/authentication/create-session-with-login-(do-not-use)>`__
- ✘ `Create Guest Session <https://developers.themoviedb.org/3/authentication/create-guest-session>`__

CERTIFICATIONS
~~~~~~~~~~~~~~
- `Get Movie Certifications <https://developers.themoviedb.org/3/certifications/get-movie-certifications>`__
- `Get TV Certifications <https://developers.themoviedb.org/3/certifications/get-tv-certifications>`__

CHANGES
~~~~~~~
- `Get Movie Change List <https://developers.themoviedb.org/3/changes/get-movie-change-list>`__
- `Get TV Change List <https://developers.themoviedb.org/3/changes/get-tv-change-list>`__
- `Get Person Change List <https://developers.themoviedb.org/3/changes/get-person-change-list>`__

COLLECTIONS
~~~~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/collections/get-details>`__
- `Get Images <https://developers.themoviedb.org/3/collections/get-images>`__

COMPANIES
~~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/companies/get-details>`__
- `Get Movies <https://developers.themoviedb.org/3/companies/get-movies>`__

CONFIGURATION
~~~~~~~~~~~~~
- `Get API Configuration <https://developers.themoviedb.org/3/configuration/get-api-configuration>`__

CREDITS
~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/credits/get-details>`__

DISCOVER
~~~~~~~~
- `Movie Discover <https://developers.themoviedb.org/3/discover/movie-discover>`__
- `TV Discover <https://developers.themoviedb.org/3/discover/tv-discover>`__

FIND
~~~~
- ✘ `Find by ID <https://developers.themoviedb.org/3/find/find-by-id>`__

GENRES
~~~~~~
- ✘ `Get Movie List <https://developers.themoviedb.org/3/genres/get-movie-list>`__
- ✘ `Get TV List <https://developers.themoviedb.org/3/genres/get-tv-list>`__
- `Get Movies <https://developers.themoviedb.org/3/genres/get-movies>`__

GUEST SESSIONS
~~~~~~~~~~~~~~
- `Get Rated Movies <https://developers.themoviedb.org/3/guest-sessions/get-rated-movies>`__
- `Get Rated TV Shows <https://developers.themoviedb.org/3/guest-sessions/get-rated-tv-shows>`__
- `Get Rated TV Episodes <https://developers.themoviedb.org/3/guest-sessions/get-rated-tv-episodes>`__

JOBS
~~~~
- `Get Jobs <https://developers.themoviedb.org/3/jobs/get-jobs>`__

KEYWORDS
~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/keywords/get-details>`__
- `Get Movies <https://developers.themoviedb.org/3/keywords/get-movies>`__

LISTS
~~~~~
- `v4 or v3 lists? <https://developers.themoviedb.org/3/lists/v4-or-v3-lists?>`__
- `Get Details <https://developers.themoviedb.org/3/lists/get-details>`__
- `Check Item Status <https://developers.themoviedb.org/3/lists/check-item-status>`__
- `Create List <https://developers.themoviedb.org/3/lists/create-list>`__
- `Add Movie <https://developers.themoviedb.org/3/lists/add-movie>`__
- `Remove Movie <https://developers.themoviedb.org/3/lists/remove-movie>`__
- `Clear List <https://developers.themoviedb.org/3/lists/clear-list>`__
- `Delete List <https://developers.themoviedb.org/3/lists/delete-list>`__

MOVIES
~~~~~~
- ✘ `Get Details <https://developers.themoviedb.org/3/movies/get-details>`__
- ✘ `Get Account States <https://developers.themoviedb.org/3/movies/get-account-states>`__
- ✘ `Get Alternative Titles <https://developers.themoviedb.org/3/movies/get-alternative-titles>`__
- ✘ `Get Changes <https://developers.themoviedb.org/3/movies/get-changes>`__
- ✘ `Get Credits <https://developers.themoviedb.org/3/movies/get-credits>`__
- ✘ `Get Images <https://developers.themoviedb.org/3/movies/get-images>`__
- ✘ `Get Keywords <https://developers.themoviedb.org/3/movies/get-keywords>`__
- ✘ `Get Release Dates <https://developers.themoviedb.org/3/movies/get-release-dates>`__
- ✘ `Get Videos <https://developers.themoviedb.org/3/movies/get-videos>`__
- ✘ `Get Translations <https://developers.themoviedb.org/3/movies/get-translations>`__
- ✘ `Get Recommendations <https://developers.themoviedb.org/3/movies/get-recommendations>`__
- ✘ `Get Similar Movies <https://developers.themoviedb.org/3/movies/get-similar-movies>`__
- ✘ `Get Reviews <https://developers.themoviedb.org/3/movies/get-reviews>`__
- ✘ `Get Lists <https://developers.themoviedb.org/3/movies/get-lists>`__
- ✘ `Rate Movie <https://developers.themoviedb.org/3/movies/rate-movie>`__
- ✘ `Delete Rating <https://developers.themoviedb.org/3/movies/delete-rating>`__
- ✘ `Get Latest <https://developers.themoviedb.org/3/movies/get-latest>`__
- ✘ `Get Now Playing <https://developers.themoviedb.org/3/movies/get-now-playing>`__
- ✘ `Get Popular <https://developers.themoviedb.org/3/movies/get-popular>`__
- ✘ `Get Top Rated <https://developers.themoviedb.org/3/movies/get-top-rated>`__
- ✘ `Get Upcoming <https://developers.themoviedb.org/3/movies/get-upcoming>`__

NETWORKS
~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/networks/get-details>`__

PEOPLE
~~~~~~
- `Get Details <https://developers.themoviedb.org/3/people/get-details>`__
- `Get Movie Credits <https://developers.themoviedb.org/3/people/get-movie-credits>`__
- `Get TV Credits <https://developers.themoviedb.org/3/people/get-tv-credits>`__
- `Get Combined Credits <https://developers.themoviedb.org/3/people/get-combined-credits>`__
- `Get External IDs <https://developers.themoviedb.org/3/people/get-external-ids>`__
- `Get Images <https://developers.themoviedb.org/3/people/get-images>`__
- `Get Tagged Images <https://developers.themoviedb.org/3/people/get-tagged-images>`__
- `Get Changes <https://developers.themoviedb.org/3/people/get-changes>`__
- `Get Latest <https://developers.themoviedb.org/3/people/get-latest>`__
- `Get Popular <https://developers.themoviedb.org/3/people/get-popular>`__

REVIEWS
~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/reviews/get-details>`__

SEARCH
~~~~~~
- `Search Companies <https://developers.themoviedb.org/3/search/search-companies>`__
- `Search Collections <https://developers.themoviedb.org/3/search/search-collections>`__
- `Search Keywords <https://developers.themoviedb.org/3/search/search-keywords>`__
- `Search Movies <https://developers.themoviedb.org/3/search/search-movies>`__
- `Multi Search <https://developers.themoviedb.org/3/search/multi-search>`__
- `Search People <https://developers.themoviedb.org/3/search/search-people>`__
- `Search TV Shows <https://developers.themoviedb.org/3/search/search-tv-shows>`__

TIMEZONES
~~~~~~~~~
- `Get List <https://developers.themoviedb.org/3/timezones/get-list>`__

TV
~~
- `Get Details <https://developers.themoviedb.org/3/tv/get-details>`__
- `Get Account States <https://developers.themoviedb.org/3/tv/get-account-states>`__
- `Get Alternative Titles <https://developers.themoviedb.org/3/tv/get-alternative-titles>`__
- `Get Changes <https://developers.themoviedb.org/3/tv/get-changes>`__
- `Get Content Ratings <https://developers.themoviedb.org/3/tv/get-content-ratings>`__
- `Get Credits <https://developers.themoviedb.org/3/tv/get-credits>`__
- `Get External IDs <https://developers.themoviedb.org/3/tv/get-external-ids>`__
- `Get Images <https://developers.themoviedb.org/3/tv/get-images>`__
- `Get Keywords <https://developers.themoviedb.org/3/tv/get-keywords>`__
- `Get Recommendations <https://developers.themoviedb.org/3/tv/get-recommendations>`__
- `Get Similar TV Shows <https://developers.themoviedb.org/3/tv/get-similar-tv-shows>`__
- `Get Translations <https://developers.themoviedb.org/3/tv/get-translations>`__
- `Get Videos <https://developers.themoviedb.org/3/tv/get-videos>`__
- `Rate TV Show <https://developers.themoviedb.org/3/tv/rate-tv-show>`__
- `Delete Rating <https://developers.themoviedb.org/3/tv/delete-rating>`__
- `Get Latest <https://developers.themoviedb.org/3/tv/get-latest>`__
- `Get TV Airing Today <https://developers.themoviedb.org/3/tv/get-tv-airing-today>`__
- `Get TV On The Air <https://developers.themoviedb.org/3/tv/get-tv-on-the-air>`__
- `Get Popular <https://developers.themoviedb.org/3/tv/get-popular>`__
- `Get Top Rated <https://developers.themoviedb.org/3/tv/get-top-rated>`__

TV SEASONS
~~~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/tv-seasons/get-details>`__
- `Get Changes <https://developers.themoviedb.org/3/tv-seasons/get-changes>`__
- `Get Account States <https://developers.themoviedb.org/3/tv-seasons/get-account-states>`__
- `Get Credits <https://developers.themoviedb.org/3/tv-seasons/get-credits>`__
- `Get External IDs <https://developers.themoviedb.org/3/tv-seasons/get-external-ids>`__
- `Get Images <https://developers.themoviedb.org/3/tv-seasons/get-images>`__
- `Get Videos <https://developers.themoviedb.org/3/tv-seasons/get-videos>`__

TV EPISODES
~~~~~~~~~~~
- `Get Details <https://developers.themoviedb.org/3/tv-episodes/get-details>`__
- `Get Changes <https://developers.themoviedb.org/3/tv-episodes/get-changes>`__
- `Get Account States <https://developers.themoviedb.org/3/tv-episodes/get-account-states>`__
- `Get Credits <https://developers.themoviedb.org/3/tv-episodes/get-credits>`__
- `Get TV Episode External IDs <https://developers.themoviedb.org/3/tv-episodes/get-tv-episode-external-ids>`__
- `Get Images <https://developers.themoviedb.org/3/tv-episodes/get-images>`__
- `Rate TV Episode <https://developers.themoviedb.org/3/tv-episodes/rate-tv-episode>`__
- `Delete Rating <https://developers.themoviedb.org/3/tv-episodes/delete-rating>`__
- `Get Videos <https://developers.themoviedb.org/3/tv-episodes/get-videos>`__

Running tests
-------------

Make sure that next files are presented in project's directory:

- **key** with ``TMDb`` API key (`instructions <https://developers.themoviedb.org/3/getting-started/introduction>`_),
  e.g.
  ::

    c15d35806311efebcecd5faabe7eaffc

- **login** with ``TMDb`` login info (user name & password separated by newline),
  e.g.
  ::

    johndoe
    youwillneverguess

Plain

.. code-block:: bash

  ./set-api-key.sh ./set-login.sh python3.5 setup.py test

Inside ``Docker`` container

.. code-block:: bash

  ./set-env.sh docker-compose up
